Leaflet.MeasureControl
======================

Leaflet control to mesure distances on the map.

Requires [Leaflet.Draw](https://github.com/leaflet/Leaflet.Draw#readme)

Check out the [demo](http://makinacorpus.github.io/Leaflet.MeasureControl/)


Usage
-----

As map option :

```

var map = L.map('map', {measureControl:true});

```

Or like any control :


```

L.Control.measureControl().addTo(map);

```


Authors
-------

* Gilles Bassière

[![Makina Corpus](http://depot.makina-corpus.org/public/logo.gif)](http://makinacorpus.com)
